==> apache-juneau-8.0.0-bin.zip: src/main/java/org/apache/juneau/examples/rest/petstore/ExpiresAfter.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              * 
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.examples.rest.petstore;

import java.util.*;

import org.apache.juneau.http.annotation.*;

@ResponseHeader(
	name="X-Expires-After",
	type="string",
	format="date-time",
	description="Date in UTC when token expires",
	example="2012-10-21"
)
public class ExpiresAfter {
	private final Calendar c;
	public ExpiresAfter(Date d) {
		this.c = new GregorianCalendar();
		c.setTime(d);
	}
	public Calendar toCalendar() {
		return c;
	}
}

==> apache-juneau-8.1.0-bin.zip: src/main/java/org/apache/juneau/examples/rest/petstore/ExpiresAfter.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.examples.rest.petstore;

import java.util.*;

import org.apache.juneau.http.annotation.*;

/**
 * X-Expires-After custom HTTP header.
 *
 * <h5 class='section'>See Also:</h5>
 * <ul class='doctree'>
 * 	<li class='extlink'>{@source}
 * </ul>
 */
@ResponseHeader(
	name="X-Expires-After",
	type="string",
	format="date-time",
	description="Date in UTC when token expires",
	example="2012-10-21"
)
public class ExpiresAfter {
	private final Calendar c;

	/**
	 * Constructor.
	 *
	 * @param d The header value.
	 */
	public ExpiresAfter(Date d) {
		this.c = new GregorianCalendar();
		c.setTime(d);
	}

	/**
	 * The header value.
	 * @return The header value.
	 */
	public Calendar toCalendar() {
		return c;
	}
}
